@@ -2,7 +2,7 @@ package SOAP::WSDL::Generator::Iterator::WSDL11;
 use strict; use warnings;
 use Class::Std::Fast;
 
-use version; our $VERSION = qv('2.00.05');
+use version; our $VERSION = qv('2.00.07');
 
 my %definitions_of  :ATTR(:name<definitions>    :default<[]>);
 my %nodes_of        :ATTR(:name<nodes>          :default<[]>);
@@ -73,7 +73,8 @@ my %METHOD_OF = (
             $node->get_type()
                 ? do {
                     die "unsupported global type <"
-                        . $node->get_type . "> found in part ". $node->get_name();
+                        . $node->get_type . "> found in part <". $node->get_name() . ">\n"
+                        . "Looks like a rpc/literal WSDL, which is not supported by SOAP::WSDL\n";
                     ## use this once we can auto-generate an element for RPC bindings
                     # $types->find_type( $node->expand($node->get_type) )
                 }
